# -*- coding: utf-8 -*-
"""
KM3NeT Data Definitions v2.2.0
https://git.km3net.de/common/km3net-dataformat
"""

# module_status
data = dict(
    MODULE_DISABLE= 0,
    COMPASS_DISABLE= 1,
    HYDROPHONE_DISABLE= 2,
    PIEZO_DISABLE= 3,
    MODULE_OUT_OF_SYNC= 4,
)
