# -*- coding: utf-8 -*-
"""
KM3NeT Data Definitions v2.2.0
https://git.km3net.de/common/km3net-dataformat
"""

# weightlist
data = dict(
    WEIGHTLIST_GENERATION_AREA=0,
    WEIGHTLIST_GENERATION_VOLUME=0,
    WEIGHTLIST_DIFFERENTIAL_EVENT_RATE=1,
    WEIGHTLIST_EVENT_RATE=2,
    WEIGHTLIST_RESCALED_EVENT_RATE1=3,
    WEIGHTLIST_RESCALED_EVENT_RATE2=4,
    WEIGHTLIST_RUN_BY_RUN_WEIGHT=5,
)
